import webpack from 'webpack';

import {
  resolvePath,
  findPathThatExist,
  getWebpackConfigByPath,
} from '../utils';

const IS_PRODUCTION = process.env.NODE_ENV === 'production';

export default function build() {
  const webpackConfigPath = findPathThatExist(
    resolvePath('webpack.config.js'),
    resolvePath('webpack.config.babel.js')
  );

  if (!webpackConfigPath) {
    return Promise.reject(new Error(`Webpack config ${webpackConfigPath} is not exist`));
  }

  const config = getWebpackConfigByPath(webpackConfigPath);

  const compiler = webpack(config);

  if (IS_PRODUCTION) {
    return new Promise((resolve, reject) => {
      compiler.run(error => {
        if (error) {
          reject(error);
          return;
        }

        resolve(compiler);
      });
    });
  }

  return Promise.resolve(compiler);
}
