import WebpackDevServer from 'webpack-dev-server';
import pushStateServer from 'pushstate-server';

import logger from '../initializer/logger';

import {
  resolvePath,
} from '../utils';

import {
  PORT,
} from '../config';

import build from './build';

const IS_PRODUCTION = process.env.NODE_ENV === 'production';

export default function start() {
  const PUBLIC_PATH = resolvePath('public');

  build()
    .then(compiler => {
      if (IS_PRODUCTION) {
        pushStateServer.start({
          port: PORT,
          directory: PUBLIC_PATH,
        });

        return;
      }

      const devServer = new WebpackDevServer(compiler, {
        hot: true,
        noInfo: true,
        inline: true,
        historyApiFallback: true,
        contentBase: PUBLIC_PATH,
      });

      devServer.listen(PORT);

      logger.info(`Server started at ${PORT} in ${IS_PRODUCTION ? 'Production' : 'Development'}`);
    })
    .catch(error => {
      logger.error(error);
    });
}
